mcp_dart_cli library
Command-line tools for MCP development.
The package is primarily consumed through the mcp_dart executable. This
library exists so package analysis and generated documentation can describe
the executable package itself without exposing an additional public API.